@@ -7,7 +7,7 @@ use strict;
 use warnings;
 use Perl::Tidy qw();
 
-our $VERSION = '1.11';
+our $VERSION = '1.12';
 
 use Perl::Tidy::Sweetened::Pluggable;
 use Perl::Tidy::Sweetened::Keyword::Block;
@@ -57,7 +57,7 @@ $plugins->add_filter(
         marker      => 'CLASS',
         replacement => 'package',
         clauses =>
-          [ '(with(\s+\w+)*)?', '(extends \s+ \w+)?', '(is(\s+\w+)*)?', ],
+          [ '(with(\s+\w+)*)?', '(extends \s+ [\w|:]+)?', '(is(\s+\w+)*)?', ],
     ) );
 
 # Create a twigil filter for:
@@ -88,7 +88,7 @@ Perl::Tidy::Sweetened - Tweaks to Perl::Tidy to support some syntactic sugar
 
 =head1 VERSION
 
-version 1.11
+version 1.12
 
 =head1 STATUS
 
@@ -161,6 +161,10 @@ Gregoy Oschwald (@oschwal)
 
 Curtis Brandt (@aggrolite)
 
+=item *
+
+@pblaberge
+
 =back
 
 =head1 SOURCE
